@@ -126,11 +126,28 @@ static void callforwarding_cancel_all_reply (GError *error)
   first = TRUE;
 }
 
+static void remove_all_response (GtkDialog *confirmation,
+                                 gint response,
+                                 gpointer user_data)
+{
+  gtk_widget_hide_all (GTK_WIDGET(confirmation));
+  if (response == GTK_RESPONSE_OK)
+  {
+    hildon_gtk_window_set_progress_indicator (GTK_WINDOW(dialog), TRUE);
+    gtk_widget_set_sensitive (GTK_WIDGET(dialog), FALSE);
+    callforwarding_cancel (5, callforwarding_cancel_all_reply);
+  }
+  gtk_widget_destroy (GTK_WIDGET(confirmation));
+}
+
 static void remove_all_clicked (GtkWidget *button, gpointer type)
 {
-  hildon_gtk_window_set_progress_indicator (GTK_WINDOW(dialog), TRUE);
-  gtk_widget_set_sensitive (GTK_WIDGET(dialog), FALSE);
-  callforwarding_cancel (5, callforwarding_cancel_all_reply);
+  GtkWidget *confirm = hildon_note_new_confirmation (
+                        GTK_WINDOW(dialog),
+                        _("Remove all?"));
+  g_signal_connect (G_OBJECT(confirm), "response",
+                    G_CALLBACK(remove_all_response), NULL);
+  gtk_widget_show_all (confirm);
 }
 
 static void dialog_response (GtkDialog *dialog,
